@@ -21,26 +21,18 @@
 # module name, this one, they are not used here though.
 # pylint: disable=W0401,W0614
 
-from .templates.CodeTemplatesMain import *
-from .templates.CodeTemplatesConstants import *
+from nuitka.Options import isDebug
 
+from .templates.CodeTemplatesCalls import *
+from .templates.CodeTemplatesConstants import *
+from .templates.CodeTemplatesExceptions import *
+from .templates.CodeTemplatesFrames import *
 from .templates.CodeTemplatesFunction import *
 from .templates.CodeTemplatesGeneratorFunction import *
-
+from .templates.CodeTemplatesIterators import *
+from .templates.CodeTemplatesMain import *
 from .templates.CodeTemplatesParameterParsing import *
-
-from .templates.CodeTemplatesExceptions import *
-from .templates.CodeTemplatesImporting import *
-from .templates.CodeTemplatesPrinting import *
-from .templates.CodeTemplatesBranches import *
-from .templates.CodeTemplatesTuples import *
-from .templates.CodeTemplatesLists import *
-from .templates.CodeTemplatesDicts import *
-from .templates.CodeTemplatesCalls import *
-from .templates.CodeTemplatesLoops import *
-from .templates.CodeTemplatesSets import *
-
-from .templates.CodeTemplatesExecEval import *
+from .templates.CodeTemplatesVariables import *
 
 
 def enableDebug():
@@ -60,7 +52,7 @@ def enableDebug():
             return self.value
 
         def __mod__(self, other):
-            assert type( other ) is dict, self.name
+            assert type(other) is dict, self.name
 
             for key in other.keys():
                 if "%%(%s)" % key not in self.value:
@@ -75,7 +67,7 @@ def enableDebug():
             return self.value % other
 
         def split(self, sep):
-            return self.value.split( sep )
+            return self.value.split(sep)
 
     from nuitka.__past__ import iterItems
 
@@ -91,7 +83,6 @@ def enableDebug():
                 template_value
             )
 
-from nuitka.Options import isDebug
 
 if isDebug():
     enableDebug()
