@@ -28,6 +28,8 @@ And releasing of values, as this is what the error case commonly does.
 
 """
 
+from nuitka import Utils
+
 from . import CodeTemplates
 from .ExceptionCodes import getExceptionIdentifier
 from .Indentation import indented
@@ -100,34 +102,34 @@ def getErrorFormatExitBoolCode(condition, exception, args, emit, context):
     if len(args) == 1:
         from .ConstantCodes import getModuleConstantCode
 
-        set_exception = """\
-exception_type = INCREASE_REFCOUNT( %s );
-exception_value = %s;
-exception_tb = NULL;""" % (
-            exception,
-            getModuleConstantCode(
+        set_exception = [
+            """exception_type = INCREASE_REFCOUNT( %s );""" % exception,
+            """exception_value = %s;""" % getModuleConstantCode(
                 constant = args[0],
-                context  = context
-            )
-        )
+            ),
+            """exception_tb = NULL;"""
+        ]
     else:
         assert False, args
 
+
+    if Utils.python_version >= 300 and context.isExceptionPublished():
+        set_exception += [
+            "ADD_EXCEPTION_CONTEXT( &exception_type, &exception_value );",
+        ]
+
     emit(
-        indented(
-            CodeTemplates.template_error_format_string_exception % {
-                "condition"        : condition,
-                "exception_exit"   : context.getExceptionEscape(),
-                "set_exception"    : indented(set_exception),
-                "release_temps"    : indented(
-                    getErrorExitReleaseCode(context)
-                ),
-                "line_number_code" : indented(
-                    getLineNumberUpdateCode(context)
-                )
-            },
-            0
-        )
+        CodeTemplates.template_error_format_string_exception % {
+            "condition"        : condition,
+            "exception_exit"   : context.getExceptionEscape(),
+            "set_exception"    : indented(set_exception),
+            "release_temps"    : indented(
+                getErrorExitReleaseCode(context)
+            ),
+            "line_number_code" : indented(
+                getLineNumberUpdateCode(context)
+            )
+        }
     )
 
 
