@@ -30,11 +30,13 @@ def getReRaiseExceptionCode(emit, context):
 
     if context.isExceptionPublished():
         emit(
-            "RERAISE_EXCEPTION( &exception_type, &exception_value, &exception_tb );"
+            """\
+RERAISE_EXCEPTION( &exception_type, &exception_value, &exception_tb );"""
         )
         emit(
             """\
-if (exception_tb && exception_tb->tb_frame == %(frame_identifier)s) %(frame_identifier)s->f_lineno = exception_tb->tb_lineno;""" % {
+if (exception_tb && exception_tb->tb_frame == %(frame_identifier)s) \
+%(frame_identifier)s->f_lineno = exception_tb->tb_lineno;""" % {
                 "frame_identifier" : context.getFrameHandle()
             }
         )
@@ -89,7 +91,7 @@ def getRaiseExceptionWithTypeCode(raise_type_name, emit, context):
     )
 
     emit(
-        "RAISE_EXCEPTION_WITH_TYPE( &exception_type, &exception_value, &exception_tb);"
+        "RAISE_EXCEPTION_WITH_TYPE( &exception_type, &exception_value, &exception_tb );"
     )
 
     emit(
