@@ -1,4 +1,4 @@
-#     Copyright 2013, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2014, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -27,26 +27,38 @@ needed except for technical reasons.
 """
 
 
-from nuitka import Utils
-from nuitka.codegen import BlobCodes, CodeTemplates
-from nuitka.codegen.Indentation import indented
+from logging import info
 
+from nuitka import Options
+from nuitka.codegen import CodeTemplates, ConstantCodes
+from nuitka.codegen.Indentation import indented
 
 frozen_modules = []
 
-def addFrozenModule( frozen_module ):
+def addFrozenModule(frozen_module):
+    assert not isFrozenModule(frozen_module[0]), frozen_module[0]
+
     frozen_modules.append(frozen_module)
 
 def getFrozenModuleCount():
     return len(frozen_modules)
 
-stream_data = BlobCodes.StreamData()
+def isFrozenModule(module_name):
+    for frozen_module in frozen_modules:
+        frozen_module_name, _code_data, _is_package, _filename, _is_late = \
+          frozen_module
+
+        if module_name == frozen_module_name:
+            return True
+    return False
+
+stream_data = ConstantCodes.stream_data
 
 def generateBytecodeFrozenCode():
     frozen_defs = []
 
     for frozen_module in frozen_modules:
-        module_name, code_data, is_package = frozen_module
+        module_name, code_data, is_package, _filename, _is_late = frozen_module
 
         size = len(code_data)
 
@@ -54,10 +66,6 @@ def generateBytecodeFrozenCode():
         if is_package:
             size = -size
 
-        if Utils.python_version >= 300:
-            module_name = module_name.decode()
-
-
         frozen_defs.append(
             """\
 {{ (char *)"{module_name}", (unsigned char *){data}, {size} }},""".format(
@@ -70,7 +78,9 @@ def generateBytecodeFrozenCode():
             )
         )
 
+        if Options.isShowInclusion():
+            info("Embedded as frozen module '%s'.", module_name)
+
     return CodeTemplates.template_frozen_modules % {
-        "stream_data": "".join(stream_data.encodeStreamData()),
-        "frozen_modules": indented(frozen_defs)
+        "frozen_modules" : indented(frozen_defs)
     }
