@@ -1,4 +1,4 @@
-#     Copyright 2013, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2014, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -26,58 +26,81 @@ anymore, if we start to not know where their value goes.
 
 from .NodeBases import (
     ExpressionBuiltinSingleArgBase,
-    StatementChildrenHavingBase,
     ExpressionMixin,
-    NodeBase
+    NodeBase,
+    StatementChildrenHavingBase
 )
 
 
-class ExpressionBuiltinGlobals( NodeBase, ExpressionMixin ):
+class ExpressionBuiltinGlobals(NodeBase, ExpressionMixin):
     kind = "EXPRESSION_BUILTIN_GLOBALS"
 
-    def __init__( self, source_ref ):
-        NodeBase.__init__( self, source_ref = source_ref )
+    def __init__(self, source_ref):
+        NodeBase.__init__(
+            self,
+            source_ref = source_ref
+        )
 
-    def computeExpression( self, constraint_collection ):
+    def computeExpression(self, constraint_collection):
         return self, None, None
 
+    def mayHaveSideEffects(self):
+        return False
 
-class ExpressionBuiltinLocals( NodeBase, ExpressionMixin ):
+    def mayRaiseException(self, exception_type):
+        return False
+
+    def mayBeNone(self):
+        return None
+
+
+class ExpressionBuiltinLocals(NodeBase, ExpressionMixin):
     kind = "EXPRESSION_BUILTIN_LOCALS"
 
-    def __init__( self, source_ref ):
-        NodeBase.__init__( self, source_ref = source_ref )
+    def __init__(self, source_ref):
+        NodeBase.__init__(
+            self,
+            source_ref = source_ref
+        )
 
-    def computeExpression( self, constraint_collection ):
+    def computeExpression(self, constraint_collection):
         # Just inform the collection that all escaped.
-        for variable_ref in constraint_collection.getActiveVariables():
-            variable = variable_ref
-
-            while variable.isReference():
-                variable = variable.getReferenced()
+        for variable in constraint_collection.getActiveVariables():
 
             # TODO: Currently this is a bit difficult to express in a positive
-            # way
-            if not variable.isTempKeeperVariable() and not variable.isTempVariable():
+            # way, but we want to have only local variables.
+            if not variable.isTempVariable() and \
+               not variable.isModuleVariable():
                 variable_trace = constraint_collection.getVariableCurrentTrace(
-                    variable_ref
+                    variable
                 )
 
-                variable_trace.addUsage( self )
+                variable_trace.addUsage(self)
 
         return self, None, None
 
-    def needsLocalsDict( self ):
+    def needsLocalsDict(self):
         return self.getParentVariableProvider().isEarlyClosure() and \
-               ( not self.getParent().isStatementReturn() or self.getParent().isExceptionDriven() )
+               not self.getParent().isStatementReturn()
+
+    def mayHaveSideEffects(self):
+        return False
+
+    def mayRaiseException(self, exception_type):
+        return False
+
+    def mayBeNone(self):
+        return None
 
 
-class StatementSetLocals( StatementChildrenHavingBase ):
+class StatementSetLocals(StatementChildrenHavingBase):
     kind = "STATEMENT_SET_LOCALS"
 
-    named_children = ( "new_locals", )
+    named_children = (
+        "new_locals",
+    )
 
-    def __init__( self, new_locals, source_ref ):
+    def __init__(self, new_locals, source_ref):
         StatementChildrenHavingBase.__init__(
             self,
             values     = {
@@ -86,45 +109,43 @@ class StatementSetLocals( StatementChildrenHavingBase ):
             source_ref = source_ref
         )
 
-    def needsLocalsDict( self ):
+    def needsLocalsDict(self):
         return True
 
-    getNewLocals = StatementChildrenHavingBase.childGetter( "new_locals" )
+    def mayRaiseException(self, exception_type):
+        return self.getNewLocals().mayRaiseException(exception_type)
 
-    def computeStatement( self, constraint_collection ):
-        # Make sure that we don't even assume "unset" of things not set yet for anything.
+    getNewLocals = StatementChildrenHavingBase.childGetter("new_locals")
+
+    def computeStatement(self, constraint_collection):
+        # Make sure that we don't even assume "unset" of things not set yet for
+        # anything.
         constraint_collection.removeAllKnowledge()
 
-        constraint_collection.onExpression( self.getNewLocals() )
+        constraint_collection.onExpression(self.getNewLocals())
         new_locals = self.getNewLocals()
 
-        if new_locals.willRaiseException( BaseException ):
-            from .NodeMakingHelpers import makeStatementExpressionOnlyReplacementNode
+        if new_locals.willRaiseException(BaseException):
+            from .NodeMakingHelpers import \
+               makeStatementExpressionOnlyReplacementNode
 
             result = makeStatementExpressionOnlyReplacementNode(
                 expression = new_locals,
                 node       = self
             )
 
-            return result, "new_raise", "Setting locals already raises implicitely building new locals."
+            return result, "new_raise", """\
+Setting locals already raises implicitly building new locals."""
 
         return self, None, None
 
 
-
-class ExpressionBuiltinDir0( NodeBase, ExpressionMixin ):
-    kind = "EXPRESSION_BUILTIN_DIR0"
-
-    def __init__( self, source_ref ):
-        NodeBase.__init__( self, source_ref = source_ref )
-
-    def computeExpression( self, constraint_collection ):
-        return self, None, None
-
-
-class ExpressionBuiltinDir1( ExpressionBuiltinSingleArgBase ):
+class ExpressionBuiltinDir1(ExpressionBuiltinSingleArgBase):
     kind = "EXPRESSION_BUILTIN_DIR1"
 
-    def computeExpression( self, constraint_collection ):
+    def computeExpression(self, constraint_collection):
         # TODO: Quite some cases should be possible to predict.
         return self, None, None
+
+    def mayBeNone(self):
+        return None
