@@ -1,4 +1,4 @@
-#     Copyright 2013, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2014, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -17,19 +17,18 @@
 #
 """ Return node
 
-This one exits functions. The only other exit is the default exit of functions with 'None'
-value, if no return is done.
+This one exits functions. The only other exit is the default exit of functions with 'None' value, if no return is done.
 """
 
 from .NodeBases import StatementChildrenHavingBase
 
 
-class StatementReturn( StatementChildrenHavingBase ):
+class StatementReturn(StatementChildrenHavingBase):
     kind = "STATEMENT_RETURN"
 
-    named_children = ( "expression", )
+    named_children = ("expression",)
 
-    def __init__( self, expression, source_ref ):
+    def __init__(self, expression, source_ref):
         StatementChildrenHavingBase.__init__(
             self,
             values     = {
@@ -40,27 +39,21 @@ class StatementReturn( StatementChildrenHavingBase ):
 
         self.exception_driven = None
 
-    getExpression = StatementChildrenHavingBase.childGetter( "expression" )
+    getExpression = StatementChildrenHavingBase.childGetter(
+        "expression"
+    )
 
-    def isStatementAborting( self ):
+    def isStatementAborting(self):
         return True
 
-    def mayRaiseException( self, exception_type ):
-        return self.getExpression().mayRaiseException( exception_type )
+    def mayRaiseException(self, exception_type):
+        return self.getExpression().mayRaiseException(exception_type)
 
-    def setExceptionDriven( self, value ):
-        self.exception_driven = value
-
-    def isExceptionDriven( self ):
-        assert self.exception_driven is not None
-
-        return self.exception_driven
-
-    def computeStatement( self, constraint_collection ):
-        constraint_collection.onExpression( self.getExpression() )
+    def computeStatement(self, constraint_collection):
+        constraint_collection.onExpression(self.getExpression())
         expression = self.getExpression()
 
-        if expression.willRaiseException( BaseException ):
+        if expression.willRaiseException(BaseException):
             from .NodeMakingHelpers import makeStatementExpressionOnlyReplacementNode
 
             result = makeStatementExpressionOnlyReplacementNode(
@@ -68,15 +61,16 @@ class StatementReturn( StatementChildrenHavingBase ):
                 node       = self
             )
 
-            return result, "new_raise", "Return statement raises in returned expression, removed return"
+            return result, "new_raise", """\
+Return statement raises in returned expression, removed return."""
 
         return self, None, None
 
 
-class StatementGeneratorReturn( StatementReturn ):
+class StatementGeneratorReturn(StatementReturn):
     kind = "STATEMENT_GENERATOR_RETURN"
 
-    def __init__( self, expression, source_ref ):
+    def __init__(self, expression, source_ref):
         StatementReturn.__init__(
             self,
             expression = expression,
