@@ -40,10 +40,9 @@ def createNamespacePackage(package_name, module_relpath):
     parts = package_name.split(".")
 
     source_ref = SourceCodeReference.fromFilenameAndLine(
-        module_relpath,
-        1,
-        FutureSpec(),
-        False
+        filename    = module_relpath,
+        line        = 1,
+        future_spec = FutureSpec(),
     )
     source_ref = source_ref.atInternal()
 
@@ -63,32 +62,32 @@ def createNamespacePackage(package_name, module_relpath):
                         source_ref    = source_ref
                     ),
                     source       = ExpressionCallNoKeywords(
-                        called = ExpressionImportName(
-                            module = ExpressionImportModule(
-                                module_name    = "_frozen_importlib",
-                                import_list    = (),
-                                level          = 0,
-                                source_ref     = source_ref
+                        called     = ExpressionImportName(
+                            module      = ExpressionImportModule(
+                                module_name = "_frozen_importlib",
+                                import_list = (),
+                                level       = 0,
+                                source_ref  = source_ref
                             ),
                             import_name = "_NamespacePath",
                             source_ref  = source_ref
                         ),
-                        args = ExpressionConstantRef(
+                        args       = ExpressionConstantRef(
                             constant   = (
                                 package_name,
-                                [ module_relpath ],
+                                [module_relpath],
                                 None
                             ),
                             source_ref =  source_ref
                         ),
                         source_ref =  source_ref
                     ),
-                    source_ref = source_ref
+                    source_ref   = source_ref
                 )
             )
         )
     )
 
-    completeVariableClosures( package )
+    completeVariableClosures(package)
 
     return source_ref, package
